; Aquaesque/theme.jl

;; Copyright (C) 2000 Henrik Magnusson <henma887@student.liu.se>

(defgroup aquaesque "Aquaesque theme" :group appearance)

(defcustom aquaesque:inverted t
  "Swap active and inactive frame appearances."
  :type boolean
  :group (appearance aquaesque)
  :after-set after-setting-frame-option)

(let*
    ;; Update window title pixel length
    ((title-width
      (lambda (w)
	(let
	    ((w-width (car (window-dimensions w))))
	  (max 0 (min (- w-width 100) (text-width (window-name w)))))))
     
     (font (get-font "-*-lucida-medium-r-normal-*-*-100-*-*-p-*-iso8859-1"))

     (fc (list "white" "black"))
     (fc_inv (list "black" "white"))


     ;; Ugly
     (tl (list (make-image "top_left_inactive.png")
	       (make-image "top_left.png")))
     (tl_inv (list (make-image "top_left.png")
		   (make-image "top_left_inactive.png")))
     
     (tt (list (make-image "top_title_inactive.png")
	       (make-image "top_title.png")))
     (tt_inv (list (make-image "top_title.png")
		   (make-image "top_title_inactive.png")))

     (tg (list (make-image "top_gradient_inactive.png")
	       (make-image "top_gradient.png")))
     (tg_inv (list (make-image "top_gradient.png")
		   (make-image "top_gradient_inactive.png")))

     (tr (list (make-image "top_right_inactive.png")
	       (make-image "top_right.png")))
     (tr_inv (list (make-image "top_right.png")
		   (make-image "top_right_inactive.png")))

     (ci (list (make-image "close_normal.png")
	       (make-image "close_active.png")))
     (ci_inv (list (make-image "close_active.png")
		   (make-image "close_normal.png")))

     (ii (list (make-image "minimize_normal.png")
	       (make-image "minimize_active.png")))
     (ii_inv (list (make-image "minimize_active.png")
		   (make-image "minimize_normal.png")))

     (font-colors (lambda () 
		    (if aquaesque:inverted fc_inv fc)))
     
     (top-left-images (lambda () 
			(if aquaesque:inverted tl_inv tl)))
		
     (top-title-images (lambda () 
			 (if aquaesque:inverted tt_inv tt)))
     
     (top-gradient-images (lambda ()
			    (if aquaesque:inverted tg_inv tg)))
				
			    
     (top-right-images (lambda ()
			 (if aquaesque:inverted tr_inv tr)))
			          
     (close-images (lambda ()
		     (if aquaesque:inverted ci_inv ci)))
     
     (iconify-images (lambda ()
		       (if aquaesque:inverted ii_inv ii)))

     (border-images (make-image "bl.png"))

     ;; Frame definitions:
     (frame `(
	      ;; top left corner
	      ((background . ,top-left-images)
	       (left-edge . -2)
	       (top-edge . -23)
	       (class . top-left-corner))

	      ;; behind title
	      ((background . ,top-gradient-images)
	       ;;             top-title-images
	       (foreground . ,font-colors)
	       (text . ,window-name)
	       (x-justify . 4)
	       (y-justify . 6)
	       (top-edge . -23)
	       (left-edge . 5) 
	       (right-edge . 35) ;; comment out
;;	       (width . ,(lambda (w) (+ (title-width w) 13)))
	       (class . title))

	      ;; gradient
;;	      ((background . ,top-gradient-images)
;;	       (top-edge . -23)
;;	       (left-edge . ,(lambda (w) (+ (title-width w) 13)))
;;	       (right-edge . 35)
;;	       (class . title))

	      ;; iconify button
	      ((background . ,iconify-images)
	       (right-edge . 20)
	       (top-edge . -23)
	       (class . iconify-button))

	      ;; delete button
	      ((background . ,close-images)
	       (right-edge . 2)
	       (top-edge . -23)
	       (class . close-button))

	      ;; top-right corner
	      ((background . ,top-right-images)
	       (right-edge . -2)
	       (top-edge . -23)
	       (class . top-right-corner))

	      ;; left border
	      ((background . ,border-images)
	       (left-edge . -2)
	       (top-edge . 0)
	       (bottom-edge . 0)
	       (class . left-border))

	      ;; right border
	      ((background . ,border-images)
	       (right-edge . -2)
	       (top-edge . 0)
	       (bottom-edge . 0)
	       (class . right-border))

	      ;; bottom border
	      ((background . ,border-images)
	       (left-edge . 0)
	       (right-edge . 0)
	       (bottom-edge . -2)
	       (class . bottom-border))

	      ;; bottom-left corner
	      ((background . ,border-images)
	       (left-edge . -1)
	       (bottom-edge . -1)
	       (class . bottom-left-corner))

	      ;; bottom-right corner
	      ((background . ,border-images)
	       (right-edge . -1)
	       (bottom-edge . -1)
	       (class . bottom-right-corner))))

     (shaped-frame `(
		     ;; top left corner
		     ((background . ,top-left-images)
		      (left-edge . -2)
		      (top-edge . -23)
		      (class . top-left-corner))

		     ;; behind title
		     ((background . ,top-title-images)
		      (foreground . ,font-colors)
		      (text . ,window-name)
		      (x-justify . 4)
		      (y-justify . 6)
		      (top-edge . -23)
		      (left-edge . 5)
		      (width . ,(lambda (w) (+ (title-width w) 13)))
		      (class . title))

		     ;; gradient
		     ((background . ,top-gradient-images)
		      (top-edge . -23)
		      (left-edge . ,(lambda (w) (+ (title-width w) 13)))
		      (right-edge . 35)
		      (class . title))

		     ;; iconify button
		     ((background . ,iconify-images)
		      (right-edge . 20)
		      (top-edge . -23)
		      (class . iconify-button))

		     ;; delete button
		     ((background . ,close-images)
		      (right-edge . 2)
		      (top-edge . -23)
		      (class . close-button))

		     ;; top-right corner
		     ((background . ,top-right-images)
		      (right-edge . -2)
		      (top-edge . -23)
		      (class . top-right-corner))))
     
     (transient-frame `(
			;; top left corner
			((background . ,top-left-images)
			 (left-edge . -2)
			 (top-edge . -23)
			 (class . top-left-corner))

			;; behind title
			((background . ,top-gradient-images)
			 ;;             top-title-images
			 (foreground . ,font-colors)
			 (text . ,window-name)
			 (x-justify . 4)
			 (y-justify . 6)
			 (top-edge . -23)
			 (left-edge . 5)
			 (right-edge . 35) ;; comment out
;;			 (width . ,(lambda (w) (+ (title-width w) 13)))
			 (class . title))

			;; gradient
;;			((background . ,top-gradient-images)
;;			 (top-edge . -23)
;;			 (left-edge . ,(lambda (w) (+ (title-width w) 13)))
;;			 (right-edge . 35)
;;			 (class . title))

			;; iconify button
			((background . ,iconify-images)
			 (right-edge . 20)
			 (top-edge . -23)
			 (class . iconify-button))

			;; delete button
			((background . ,close-images)
			 (right-edge . 2)
			 (top-edge . -23)
			 (class . close-button))

			;; top-right corner
			((background . ,top-right-images)
			 (right-edge . -2)
			 (top-edge . -23)
			 (class . top-right-corner))

			;; left border
			((background . ,border-images)
			 (left-edge . -2)
			 (top-edge . 0)
			 (bottom-edge . 0)
			 (class . left-border))

			;; right border
			((background . ,border-images)
			 (right-edge . -2)
			 (top-edge . 0)
			 (bottom-edge . 0)
			 (class . right-border))

			;; bottom border
			((background . ,border-images)
			 (left-edge . 0)
			 (right-edge . 0)
			 (bottom-edge . -2)
			 (class . bottom-border))

			;; bottom-left corner
			((background . ,border-images)
			 (left-edge . -1)
			 (bottom-edge . -1)
			 (class . bottom-left-corner))

			;; bottom-right corner
			((background . ,border-images)
			 (right-edge . -1)
			 (bottom-edge . -1)
			 (class . bottom-right-corner))))

     (shaped-transient-frame `(
			       ;; top left corner
			       ((background . ,top-left-images)
				(left-edge . -2)
				(top-edge . -23)
				(class . top-left-corner))

			       ;; behind title
			       ((background . ,top-title-images)
				(foreground . ,font-colors)
				(text . ,window-name)
				(x-justify . 4)
				(y-justify . 6)
				(top-edge . -23)
				(left-edge . 5)
				(width . ,(lambda (w) (+ (title-width w) 13)))
				(class . title))

			       ;; gradient
			       ((background . ,top-gradient-images)
				(top-edge . -23)
				(left-edge . ,(lambda (w) (+ (title-width w) 13)))
				(right-edge . 35)
				(class . title))

			       ;; iconify button
			       ((background . ,iconify-images)
				(right-edge . 20)
				(top-edge . -23)
				(class . iconify-button))

			       ;; delete button
			       ((background . ,close-images)
				(right-edge . 2)
				(top-edge . -23)
				(class . close-button))

			       ;; top-right corner
			       ((background . ,top-right-images)
				(right-edge . -2)
				(top-edge . -23)
				(class . top-right-corner)))))
  
  (add-frame-style 'Aquaesque
		   (lambda (w type)
		     (cond ((eq type 'shaped)
			    shaped-frame)
			   ((eq type 'transient)
			    transient-frame)
			   ((eq type 'shaped-transient)
			    shaped-transient-frame)
			   ((eq type 'unframed)
			    nil-frame)
			   (t
			    frame))))
  
  (call-after-property-changed
   'WM_NAME (lambda ()
	      (rebuild-frames-with-style 'Aquaesque))))